@@ -355,14 +355,13 @@ class Worker:
             self.message_queue_client.enqueue(request_id)
 
     def _move_task_to_next_stage(self, metadata: TaskMetadata, result: list, next_batch: list, request_id: str):
+        output_blob = "%s/%s_%d" % (self.worker_name, metadata.blob_name, metadata.batch_count)
+        serialized_result = "\n".join(json.dumps(r) for r in result)
+        self.reader.upload_output_blob(output_blob, serialized_result)
+
         metadata.offset += len(result)
         metadata.batch_count += 1
         metadata.next_batch = next_batch
-
-        output_blob = "%s/%s_%d" % (self.worker_name, metadata.blob_name, metadata.batch_count)
-        serialized_result = "\n".join(json.dumps(r) for r in result)
-
-        self.reader.upload_output_blob(output_blob, serialized_result)
         self.metadata_repository.update_metadata(metadata)
         self.message_queue_client.enqueue(request_id)
 
@@ -374,7 +373,7 @@ class Worker:
         else:     
             content = []
             for batch in range(metadata.batch_count):
-                blob_content = self.reader.read_output_blob("%s/%s_%d" % (self.worker_name, blob_name, batch))
+                blob_content = self.reader.read_output_blob("%s_%d" % (blob_name, batch))
                 content.append(blob_content)
             content.append(serialized_result)
             self.reader.upload_output_blob(blob_name, "\n".join(content))
